@@ -1,6 +1,6 @@
 package App::Office::Contacts::Import::vCards::Controller::Import;
 
-use base 'App::Office::Contacts::Import::vCards::Controller';
+use parent 'App::Office::Contacts::Import::vCards::Controller';
 use strict;
 use warnings;
 
@@ -17,7 +17,7 @@ use Time::Elapsed;
 
 # We don't use Moose because we isa CGI::Application.
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 # -----------------------------------------------
 
